@@ -1,4 +1,4 @@
-/* $Id: wl.c,v 1.16 2006/05/10 03:57:57 hacki Exp $ */
+/* $Id: wl.c,v 1.18 2008/05/13 04:42:17 hacki Exp $ */
 
 /*
  * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
@@ -247,7 +247,7 @@ get_signal(const char *interface, const char *network)
 			len = nr[i].nr_nwid_len + 1;
 		else
 			len = sizeof(network_id);
-		strlcpy(network_id, nr[i].nr_nwid, len);
+		strlcpy(network_id, (const char *)nr[i].nr_nwid, len);
 		if (!strcmp(network_id, network))
 			return (nr[i].nr_rssi);
 	}
@@ -261,7 +261,7 @@ get_signal(const char *interface, const char *network)
 		uint8_t *vp;
 		sr = (struct ieee80211req_scan_result *)cp;
 		vp = (u_int8_t *)(sr + 1);
-		strlcpy(network_id, vp, sr->isr_ssid_len + 1);
+		strlcpy(network_id, (const char *)vp, sr->isr_ssid_len + 1);
 		if (!strcmp(network_id, network))
 			return (sr->isr_rssi);
 		cp += sr->isr_len;
@@ -475,7 +475,7 @@ get_nwid(const char *interface)
 		else
 			len = sizeof(network_id);
 #ifdef __OpenBSD__
-		strlcpy(network_id, nwid.i_nwid, len);
+		strlcpy(network_id, (const char *)nwid.i_nwid, len);
 #endif
 #ifdef __FreeBSD__
 		network_id[len - 1] = '\0';
