@@ -1,4 +1,4 @@
-/* $Id: xutils.h,v 1.3 2006/05/04 18:44:47 hacki Exp $ */
+/* $Id: xutils.h,v 1.4 2008/04/30 20:52:42 hacki Exp $ */
 
 /*
  * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
@@ -24,7 +24,7 @@ void		copyXPMArea(int, int, int, int, int, int);
 void		copyXBMArea(int, int, int, int, int, int);
 void		RedrawWindow(void);
 void		initXwindow(char *);
-void		openXwindow(int, char **, char **, char *, int, int);
+void		openXwindow(int, char **, char **, unsigned char *, int, int);
 unsigned long	getColor(char *, float, int *, int *, int *);
 unsigned long	getBlendedColor(char *, float, int, int, int);
 
